play method

void play()

Transitions the animation into the playing state, unless the controller is currently in the pausingBetweenAnimationsWithUserPauseRequested state, in which case it returns to the pausingBetweenAnimations state.

Call this to resume the animation if it was previously paused.

Implementation

void play() {
  if (stateNotifier.value ==
      AnimatedTextState.pausedBetweenAnimationsByUser) {
    stateNotifier.value = AnimatedTextState.pausedBetweenAnimations;
  } else {
    stateNotifier.value = AnimatedTextState.playing;
  }
}