BounceAnimatedText class

Animated Text that displays a Text element with a bouncing effect.

The text bounces in from below with an elastic curve, creating a playful and dynamic entrance animation.

Inheritance

Constructors

BounceAnimatedText(String text, {TextAlign textAlign = TextAlign.start, TextStyle? textStyle, Duration duration = const Duration(milliseconds: 1500), double bounceHeight = 50.0, Curve curve = Curves.elasticOut})

Properties

bounceHeight double
The height from which the text bounces in.
final
curve Curve
The Curve of the bounce animation.
final
duration Duration
The Duration for the Animation Controller.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
remaining Duration?
Return the remaining Duration for the Animation (when applicable).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Text for Text widget.
finalinherited
textAlign TextAlign
TextAlign property for Text widget.
finalinherited
textCharacters Characters
Same as text but as Characters.
finalinherited
textStyle TextStyle?
TextStyle property for Text widget.
finalinherited

Methods

animatedBuilder(BuildContext context, Widget? child) Widget
Widget showing animated text, based on animation value(s).
override
completeText(BuildContext context) Widget
Widget showing the complete text (when animation is complete or paused). By default, it shows a Text widget, but this may be overridden.
inherited
initAnimation(AnimationController controller) → void
Initialize the Animation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
textWidget(String data) Widget
Utility method to create a styled Text widget using the textAlign and textStyle, but you can specify the data.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited